@@ -99,9 +99,12 @@ class Database:
                     qfq_df = qfq_df.fillna(method='ffill')
                     qfq_df = qfq_df.reset_index()
                     qfq_df['index'] = qfq_df['index'].astype(str)
-                    qfq_df['index'] = qfq_df['index'].str.replace('-', '')
+                    qfq_df['index'] = qfq_df['index'].str.replace('-', '', regex=False)
                     df = pd.merge(left=df, left_on='date', right=qfq_df, right_on='index')
 
+                    print(df)
+                    time.sleep(132456)
+
                     if df['qfq_factor'].isnull().values.any():
                         df['qfq_factor'] = df['qfq_factor'].fillna(method='ffill')
 
@@ -238,12 +241,12 @@ class Database:
             year_month_involved_list.append((datetime.datetime.strptime(year_month_involved_list[-1], '%y%m') + relativedelta(months=1)).strftime('%y%m'))
 
             year_month_involved_list_str = json.dumps(str(year_month_involved_list))
-            year_month_involved_list_str = year_month_involved_list_str.replace('[', '')
-            year_month_involved_list_str = year_month_involved_list_str.replace(']', '')
-            year_month_involved_list_str = year_month_involved_list_str.replace('\'', '')
-            year_month_involved_list_str = year_month_involved_list_str.replace(',', '')
-            year_month_involved_list_str = year_month_involved_list_str.replace(' ', '_')
-            year_month_involved_list_str = year_month_involved_list_str.replace('\"', '')
+            year_month_involved_list_str = year_month_involved_list_str.replace('[', '', regex=False)
+            year_month_involved_list_str = year_month_involved_list_str.replace(']', '', regex=False)
+            year_month_involved_list_str = year_month_involved_list_str.replace('\'', '', regex=False)
+            year_month_involved_list_str = year_month_involved_list_str.replace(',', '', regex=False)
+            year_month_involved_list_str = year_month_involved_list_str.replace(' ', '_', regex=False)
+            year_month_involved_list_str = year_month_involved_list_str.replace('\"', '', regex=False)
 
             link_url = 'http://www.hkfdb.net/data_api?'
             token_str = 'token=' + str(self.authToken)
@@ -1145,17 +1148,28 @@ class Database:
             df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
 
             df['share_issued'] = df['share_issued'].astype(str)
-            df['share_issued'] = df['share_issued'].str.replace('-','')
+            df['share_issued'] = df['share_issued'].str.replace('-','', regex=False)
             df['share_issued'] = df['share_issued'].astype('int64')
 
             df = df.sort_values(by='code')
 
-            df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
+            #df['market_capital'] = df['market_capital'].map(lambda x:round(x,0))
             df['market_capital'] = df['market_capital'].astype('int64')
-            df['is_stop_trading'] = df['is_stop_trading'].map({'True': True, 'False': False})
+            df['is_stop_trading'] = df['is_stop_trading'].map({'1': True, '0': False})
 
-            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading','Category']]
-            df = df.rename(columns={'Category':'category'})
+            float_col_list = ['price','PE','EPS','dividend']
+            int_col_list = ['volume','turnover']
+            for col in float_col_list:
+                df[col] = df[col].str.replace('-', '', regex=False)
+                df[col] = df[col].str.replace('.000', '', regex=False)
+                df[col] = df[col].str.replace(',', '', regex=False)
+                df[col] = df[col].astype(float)
+
+            for col in int_col_list:
+                df[col] = df[col].astype('int64')
+            df['lot_size'] = df['lot_size'].astype(int)
+
+            df = df[['code','stock_name','price','PE','EPS','dividend','volume','turnover','share_issued','lot_size','market_capital','ipo_date','year_end_date', 'is_stop_trading','category']]
             return df
 
     def get_hk_ipo_hist(self):
@@ -1319,7 +1333,7 @@ class Database:
 
                 if deri == 'opt':
                     df = df.rename(columns={'contract_month':'year_month'})
-                    df['year_month'] = df['year_month'].str.replace('-','')
+                    df['year_month'] = df['year_month'].str.replace('-','', regex=False)
                     df['year_month'] = pd.to_datetime(df['year_month'], format='%b%y')
                     df = df.sort_values(by=['date','year_month'])
                     df['year_month'] = df['year_month'].dt.strftime('%b-%y')
